@@ -12,6 +12,10 @@
 #include "gexiv2-version.h"
 
 gboolean gexiv2_initialize(void) {
+#ifdef EXV_ENABLE_BMFF
+    Exiv2::enableBMFF();
+#endif
+
     return Exiv2::XmpParser::initialize();
 }
 
