@@ -87,9 +87,12 @@ class TestMetadata(unittest.TestCase):
                        'free',
                        'freeze_notify',
                        'from_app1_segment',
+                       'from_stream',
                        'g_type_instance',
+                       'generate_xmp_packet',
                        'get_comment',
                        'get_data',
+                       'get_exif_data',
                        'get_exif_tag_rational',
                        'get_exif_tags',
                        'get_exif_thumbnail',
@@ -102,6 +105,8 @@ class TestMetadata(unittest.TestCase):
                        'get_gps_longitude',
                        'get_iptc_tags',
                        'get_iso_speed',
+                       'get_metadata_pixel_height',
+                       'get_metadata_pixel_width',
                        'get_mime_type',
                        'get_orientation',
                        'get_pixel_height',
@@ -119,8 +124,10 @@ class TestMetadata(unittest.TestCase):
                        'get_tag_label',
                        'get_tag_long',
                        'get_tag_multiple',
+                       'get_tag_raw',
                        'get_tag_string',
                        'get_tag_type',
+                       'get_xmp_namespace_for_tag',
                        'get_xmp_packet',
                        'get_xmp_tags',
                        'handler_block',
@@ -156,6 +163,7 @@ class TestMetadata(unittest.TestCase):
                        'replace_data',
                        'replace_qdata',
                        'run_dispose',
+                       'save_external',
                        'save_file',
                        'set_comment',
                        'set_data',
@@ -163,20 +171,47 @@ class TestMetadata(unittest.TestCase):
                        'set_exif_thumbnail_from_buffer',
                        'set_exif_thumbnail_from_file',
                        'set_gps_info',
+                       'set_metadata_pixel_height',
+                       'set_metadata_pixel_width',
                        'set_orientation',
                        'set_properties',
                        'set_property',
                        'set_tag_long',
                        'set_tag_multiple',
                        'set_tag_string',
+                       'set_xmp_tag_struct',
                        'steal_data',
                        'steal_qdata',
                        'stop_emission',
                        'stop_emission_by_name',
                        'thaw_notify',
+                       'try_delete_gps_info',
+                       'try_generate_xmp_packet',
+                       'try_get_exif_tag_rational',
+                       'try_get_gps_altitude',
+                       'try_get_gps_info',
+                       'try_get_gps_latitude',
+                       'try_get_gps_longitude',
+                       'try_get_tag_description',
+                       'try_get_tag_interpreted_string',
+                       'try_get_tag_label',
+                       'try_get_tag_long',
+                       'try_get_tag_multiple',
+                       'try_get_tag_raw',
+                       'try_get_tag_string',
+                       'try_get_tag_type',
+                       'try_get_xmp_packet',
+                       'try_set_exif_tag_rational',
+                       'try_set_gps_info',
+                       'try_set_tag_long',
+                       'try_set_tag_multiple',
+                       'try_set_tag_string',
+                       'try_set_xmp_tag_struct',
+                       'try_update_gps_info',
                        'unref',
                        'unregister_all_xmp_namespaces',
                        'unregister_xmp_namespace',
+                       'update_gps_info',
                        'watch_closure',
                        'weak_ref']:
             self.assertIn(method, methods)
